@@ -1,8 +1,10 @@
 from .toolbox import (
+    BulkWriter,
+    MongodbToolboxError,
     bulk_insert_dup,
     bulk_insert_dup_retok,
     bulk_write,
     iterate_collection,
 )
 
-__version__ = "0.0.1"
+__version__ = "0.0.3"
